==> org-lsst-ccs-subsystem-fcs-main-1.4.1-sources.jar: org/lsst/ccs/subsystems/fcs/testbench/LPNHETestBenchMainModule.java <==

package org.lsst.ccs.subsystems.fcs.testbench;

import org.lsst.ccs.framework.Module;
import org.lsst.ccs.subsystems.fcs.FilterClampModule;
import org.lsst.ccs.subsystems.fcs.common.BridgeToHardware;
import org.lsst.ccs.subsystems.fcs.errors.HardwareException;

/**
 * This is the main module for the control software of the LPNHE test bench.
 * The LPNHE test bench consists on one PC104 which hosts a Canfestival C-Wrapper 
 * and a Maxon Motor to unlock or release a carousel filter clamp. The C-Wrapper starts
 * a TCPIP client which connects to the TCPIP server started by the main Module of
 * the LPNHE test bench main Module.
 * 
 * When the LPNHETestBenchMainModule starts, it starts a a TCP-IP server.
 * the can open wrapper software will connect. 
 * Then the LPNHETestBenchProxy and the Wrapper will communicate over this TCP connection 
 * with a protocol to be define.
 * In a first version :
 * 1- The TCP server is started and waits for a client connection,
 * 2- When the client connects, it sends first a key word "APCTestBench".
 * 3- When the server receives the key word "APCTestBench", it's ready to boot the hardware 
 * and receive commands.
 * @author virieux
 */
public class LPNHETestBenchMainModule extends Module  {

    private BridgeToHardware bridge;
    private FilterClampModule clampXminus;



    //FOR SPRING
    public BridgeToHardware getBridge() {
        return bridge;
    }

    //FOR SPRING
    public void setBridge(BridgeToHardware bridge) {
        this.bridge = bridge;
    }
    
    public FilterClampModule getClampXminus() {
        return clampXminus;
    }

    public void setClampXminus(FilterClampModule clampXminus) {
        this.clampXminus = clampXminus;
    }
    
    /**
     * Read and return the temperature of the clampXminus.
     * Just for the tests.
     * @return 
     */
    public double readTemperature() throws HardwareException {
        return clampXminus.updateTemperature();
    }
    
        
     /**
     * This method returns true if the C-Wrapper is connected to the tcp proxy.
     * The C-Wrapper has to send the tcpProxy clientName as a keyword before
     * any communication can begin. So if the C-Wrapper doesn't send the good
     * keyword or if it doesn't connect to the tcp proxy, this method returns 
     * false.
     */
    public boolean isHardwareConnected() {
        return bridge.isCWrapperConnected();
    }
    
    
    /**
     * returns true if the hardware is booted, identified and initialized.
     */
    public boolean isHardwareReady() {
        return bridge.isHardwareReady();
    }
    
 
    
    public void shutdown() {
        //bridge.getTcpProxy().stop();
        this.getSubsystem().shutdown();
    }

    
}

==> org-lsst-ccs-subsystem-fcs-main-1.4.4-sources.jar: org/lsst/ccs/subsystems/fcs/testbench/LPNHETestBenchMainModule.java <==

package org.lsst.ccs.subsystems.fcs.testbench;

import java.util.concurrent.atomic.AtomicBoolean;
import org.lsst.ccs.framework.Module;
import org.lsst.ccs.framework.Signal;
import org.lsst.ccs.framework.TreeWalkerDiag;
import org.lsst.ccs.subsystems.fcs.FilterClampModule;
import org.lsst.ccs.subsystems.fcs.common.BridgeToHardware;
import org.lsst.ccs.subsystems.fcs.errors.HardwareException;

/**
 * This is the main module for the control software of the LPNHE test bench.
 * The LPNHE test bench consists on one PC104 which hosts a Canfestival C-Wrapper 
 * and a Maxon Motor to unlock or release a carousel filter clamp. The C-Wrapper starts
 * a TCPIP client which connects to the TCPIP server started by the main Module of
 * the LPNHE test bench main Module.
 * 
 * When the LPNHETestBenchMainModule starts, it starts a a TCP-IP server.
 * the can open wrapper software will connect. 
 * Then the LPNHETestBenchProxy and the Wrapper will communicate over this TCP connection 
 * with a protocol to be define.
 * In a first version :
 * 1- The TCP server is started and waits for a client connection,
 * 2- When the client connects, it sends first a key word "APCTestBench".
 * 3- When the server receives the key word "APCTestBench", it's ready to boot the hardware 
 * and receive commands.
 * @author virieux
 */
public class LPNHETestBenchMainModule extends Module  {

    private BridgeToHardware bridge;
    private FilterClampModule clampXminus;
    private AtomicBoolean haltRequired;



    //FOR SPRING
    public BridgeToHardware getBridge() {
        return bridge;
    }

    //FOR SPRING
    public void setBridge(BridgeToHardware bridge) {
        this.bridge = bridge;
    }
    
    public FilterClampModule getClampXminus() {
        return clampXminus;
    }

    public void setClampXminus(FilterClampModule clampXminus) {
        this.clampXminus = clampXminus;
    }
    
    /**
     * Read and return the temperature of the clampXminus.
     * Just for the tests.
     * @return 
     */
    public double readTemperature() throws HardwareException {
        return clampXminus.updateTemperature();
    }
    
        
     /**
     * This method returns true if the C-Wrapper is connected to the tcp proxy.
     * The C-Wrapper has to send the tcpProxy clientName as a keyword before
     * any communication can begin. So if the C-Wrapper doesn't send the good
     * keyword or if it doesn't connect to the tcp proxy, this method returns 
     * false.
     */
    public boolean isHardwareConnected() {
        return bridge.isCWrapperConnected();
    }
    
    
    /**
     * returns true if the hardware is booted, identified and initialized.
     */
    
    public boolean isHardwareReady() {
        return bridge.isHardwareReady();
    }
    
 
    
//    public void shutdown() {
//        bridge.getTcpProxy().stop();
//        this.getSubsystem().shutdown();
//    }
    
//    public TreeWalkerDiag signal(Signal signal) {
//        
//        return TreeWalkerDiag.STOP;
//        
//    }
    
    @Override
    public TreeWalkerDiag signal(Signal signal) {
//        log.info("Received:" + signal.getLevel().toString());
        switch(signal.getLevel()) {
            case HALT :
                log.debug("HALT required");
                this.haltRequired.set(true);
                break;
            case INTERRUPT1 :
                break;
            case INTERRUPT2 :
                break;
            case RE_START :
                this.haltRequired.set(false);
                break;
        }
        //return TreeWalkerDiag.STOP;
        return TreeWalkerDiag.HANDLING_CHILDREN;
    }

    
}
